Struct Csr
#[repr(transparent)]pub struct Csr(pub u32);Expand description
CSR register.
Tuple Fields
0: u32Implementations
impl Csr
impl Csr
pub const fn rmvf(&self) -> bool
pub const fn rmvf(&self) -> bool
Remove reset flag Set by software to clear the value of the reset flags. It auto clears by HW after clearing reason flags.
pub const fn set_rmvf(&mut self, val: bool)
pub const fn set_rmvf(&mut self, val: bool)
Remove reset flag Set by software to clear the value of the reset flags. It auto clears by HW after clearing reason flags.
pub const fn padrstf(&self) -> bool
pub const fn padrstf(&self) -> bool
SYSTEM reset flag Reset by software by writing the RMVF bit. Set by hardware when a reset from pad occurs.
pub const fn set_padrstf(&mut self, val: bool)
pub const fn set_padrstf(&mut self, val: bool)
SYSTEM reset flag Reset by software by writing the RMVF bit. Set by hardware when a reset from pad occurs.
pub const fn porrstf(&self) -> bool
pub const fn porrstf(&self) -> bool
POWER reset flag Reset by software by writing the RMVF bit. Set by hardware when a power reset occurs from LPMURESET block.
pub const fn set_porrstf(&mut self, val: bool)
pub const fn set_porrstf(&mut self, val: bool)
POWER reset flag Reset by software by writing the RMVF bit. Set by hardware when a power reset occurs from LPMURESET block.
pub const fn sftrstf(&self) -> bool
pub const fn sftrstf(&self) -> bool
Software reset flag Reset by software by writing the RMVF bit. Set by hardware when a software reset occurs.
pub const fn set_sftrstf(&mut self, val: bool)
pub const fn set_sftrstf(&mut self, val: bool)
Software reset flag Reset by software by writing the RMVF bit. Set by hardware when a software reset occurs.
pub const fn wdgrstf(&self) -> bool
pub const fn wdgrstf(&self) -> bool
Watchdog reset flag Reset by software by writing the RMVF bit. Set by hardware when a watchdog reset from V33 domain occurs.
pub const fn set_wdgrstf(&mut self, val: bool)
pub const fn set_wdgrstf(&mut self, val: bool)
Watchdog reset flag Reset by software by writing the RMVF bit. Set by hardware when a watchdog reset from V33 domain occurs.
pub const fn lockuprstf(&self) -> bool
pub const fn lockuprstf(&self) -> bool
LOCK UP reset flag from CM0 Reset by software by writing the RMVF bit. Set by hardware from unrecoverable exception CPU. It reset V12i domain, FLASH controller and peripherals.
pub const fn set_lockuprstf(&mut self, val: bool)
pub const fn set_lockuprstf(&mut self, val: bool)
LOCK UP reset flag from CM0 Reset by software by writing the RMVF bit. Set by hardware from unrecoverable exception CPU. It reset V12i domain, FLASH controller and peripherals.