Struct Csswcr
#[repr(transparent)]pub struct Csswcr(pub u32);Expand description
CSSWCR register.
Tuple Fields
0: u32Implementations
impl Csswcr
impl Csswcr
pub const fn lsiswtrimen(&self) -> bool
pub const fn lsiswtrimen(&self) -> bool
Low speed internal RC software trimming enable.
pub const fn set_lsiswtrimen(&mut self, val: bool)
pub const fn set_lsiswtrimen(&mut self, val: bool)
Low speed internal RC software trimming enable.
pub const fn lsiswbw(&self) -> u8
pub const fn lsiswbw(&self) -> u8
This value is taken into account instead of the trimming value loaded by HW at reset if LSISWTRIMEN bit is set.
pub const fn set_lsiswbw(&mut self, val: u8)
pub const fn set_lsiswbw(&mut self, val: u8)
This value is taken into account instead of the trimming value loaded by HW at reset if LSISWTRIMEN bit is set.
pub const fn set_lsedrv(&mut self, val: Lsedrv)
pub const fn set_lsedrv(&mut self, val: Lsedrv)
GM for the external 32kHz crystal.
pub const fn hsiswtrimen(&self) -> bool
pub const fn hsiswtrimen(&self) -> bool
High speed internal RC software trimming enable.
pub const fn set_hsiswtrimen(&mut self, val: bool)
pub const fn set_hsiswtrimen(&mut self, val: bool)
High speed internal RC software trimming enable.
pub const fn hsiswbw(&self) -> u8
pub const fn hsiswbw(&self) -> u8
This value is taken into account instead of the trimming value loaded by HW at reset if HSISWTRIMEN bit is set.
pub const fn set_hsiswbw(&mut self, val: u8)
pub const fn set_hsiswbw(&mut self, val: u8)
This value is taken into account instead of the trimming value loaded by HW at reset if HSISWTRIMEN bit is set.